@@ -27,11 +27,11 @@ sub as_string{
 
 =head1 NAME
 
-TaskPipe::Role::RunInfo
+TaskPipe::Role::RunInfo - information about the run (of the current plan)
 
 =head1 DESCRIPTION
 
-provides run information (run_id, thread_id etc.)
+provides run information (job_id, thread_id etc.) for the current job/thread
 
 =head1 AUTHOR
 
