@@ -39,7 +39,7 @@ __PACKAGE__->set_primary_key("ip", "port");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Global::Result::OpenProxy
+TaskPipe::SchemaTemplate_Global::Result::OpenProxy - global schema template for open proxy source
 
 =head1 DESCRIPTION
 
