@@ -42,7 +42,7 @@ __PACKAGE__->set_primary_key("process_name", "job_id", "thread_id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Global::Result::TorThread
+TaskPipe::SchemaTemplate_Global::Result::Spawned - global schema template for C<spawned> source
 
 =head1 DESCRIPTION
 
