@@ -37,7 +37,7 @@ __PACKAGE__->set_primary_key("id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Project::Result::Error
+TaskPipe::SchemaTemplate_Project::Result::Error - schema template for the project C<error> table
 
 =head1 DESCRIPTION
 
