@@ -25,7 +25,7 @@ __PACKAGE__->set_primary_key("id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Project::Result::Pinterp
+TaskPipe::SchemaTemplate_Project::Result::Pinterp - schema template for the project C<pinterp> table
 
 =head1 DESCRIPTION
 
