@@ -29,7 +29,7 @@ __PACKAGE__->set_primary_key("id");
 
 =head1 NAME
 
-TaskPipe::SchemaTemplate_Project::Result::Run
+TaskPipe::SchemaTemplate_Project::Result::Run - schema template for project C<run> table
 
 =head1 DESCRIPTION
 
