@@ -1,6 +1,6 @@
 package TaskPipe::Task;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 use Moose;
 use Module::Runtime qw(require_module);
@@ -24,9 +24,6 @@ with 'MooseX::ConfigCascade';
 has sm => (is => 'ro', isa => 'TaskPipe::SchemaManager', required => 1);
 has gm => (is => 'ro', isa => 'TaskPipe::SchemaManager', required => 1);
 
-#has job_id => (is => 'rw', isa => 'Int', default => 0);
-#has run_id => (is => 'rw', isa => 'Int');
-
 has run_info => (is => 'ro', isa => 'TaskPipe::RunInfo', default => sub{
     TaskPipe::RunInfo->new;
 });
@@ -113,29 +110,6 @@ sub test{
 
     my $logger = Log::Log4perl->get_logger;
 
-
-
-#    my $dt = DateTime->now;
-
-#    my $out;
-#    my $output_type = $self->test_settings->output;
-#    my $outpath;
-
-#    if ( $output_type =~ /file/i ){
-
-#        my $filename = $self->test_settings->file_prefix
-#                        .$self->name.'.'
-#                        .$dt->ymd.'_'.$dt->hms
-#                        .$self->test_settings->file_suffix;
-#                        
-#        $outpath = File::Spec->catdir(
-#            $self->sm->path_settings->path('log'),
-#            $filename
-#        );
-
-#        open $out,'>:encoding(UTF-8)',$outpath or die "Could not open $outpath: $!";
-#    }
-
     my $output = "";
 
     foreach my $test_pinterp ( @{$self->test_data} ){
@@ -167,82 +141,12 @@ sub test{
     $output.= "=" x 60;
 
     $logger->info( $output );
-    #print $output if $self->test_settings->output =~ /screen/i;
 
-    #print "*** Done testing ".$self->name." ***\n";
-
-#    if ($out){
-#        print $out $output;
-#        close $out;
-#        print "Test results were printed to: $outpath\n";
-#    }
 }
 
 
 
 
-#sub test{
-#    my ($self) = @_;
-
-#    my $logger = Log::Log4perl->get_logger;
-
-#    $logger->warn("No test inputs (pinterp) defined. Assuming this task does not need it" unless $self->test_data;
-#    $logger->warn("Test set (pinterp) empty. Assuming this task does not use pinterp" if $self->test_data && ! @{$self->test_data};
-
-#    my $dt = DateTime->now;
-
-#    my $out;
-#    my $output_type = $self->test_settings->output;
-#    my $outpath;
-
-#    if ( $output_type =~ /file/i ){
-
-#        my $filename = $self->test_settings->file_prefix
-#                        .$self->name.'.'
-#                        .$dt->ymd.'_'.$dt->hms
-#                        .$self->test_settings->file_suffix;
-#                        
-#        $outpath = File::Spec->catdir(
-#            $self->sm->path_settings->path('log'),
-#            $filename
-#        );
-
-#        open $out,'>:encoding(UTF-8)',$outpath or die "Could not open $outpath: $!";
-#    }
-
-#    my $output = "";
-
-#    foreach my $test_pinterp ( @{$self->test_data} ){
-
-#        confess "Need test_pinterp" unless $test_pinterp;
-
-#        $self->pinterp( $test_pinterp );
-#        my $result = $self->action;
-
-#        $output.= "\n\n" if $output;
-#        $output.= "=" x 60;
-#        $output.= "\nTesting ".ref($self).":\n\n";
-#        $output.= "Test Pinterp: ".Dumper( $test_pinterp )."\n\n";
-#        $output.= "Result: ".Dumper( $result )."\n\n";
-#        $output.= $self->add_test_output if $self->can('add_test_output');
-
-#    }
-#    $output.= "=" x 60;
-
-#    print $output if $self->test_settings->output =~ /screen/i;
-
-#    print "*** Done testing ".$self->name." ***\n";
-
-#    if ($out){
-#        print $out $output;
-#        close $out;
-#        print "Test results were printed to: $outpath\n";
-#    }
-#}
-
-
-
-
 
 
 sub test_data{
@@ -510,7 +414,6 @@ sub execute_as_manager{
         ||  $self->settings->plan_mode eq 'branch' && ! @{$self->plan}
     );
 
-#    $self->thread_manager->run_info( $self->rinfo );
     $self->init_run;
     $self->thread_manager->init;
     $self->pipe_through;
@@ -568,7 +471,6 @@ sub get_cached_pinterp{
     }
 
     if ( ! $cached->status || $cached->status ne 'fully-cached'){
-        #$self->clear_partially_cached( $cached );
         $self->cached_pinterp( undef );
         return;
     }
@@ -655,22 +557,10 @@ sub cache_results{
         $self->cache_result( $result );
     }
 
-#    my $cp = $self->sm->table('pinterp')->find({
-#        id => +$self->cached_pinterp->id
-#    });
 
-#    ->update({
-#        status => 'fully-cached'
-#    });
-        $self->cached_pinterp->update({
-            status => 'fully-cached'
-        });
-
-#    } catch {
-
-#        confess "id was $id";
-
-#    };
+    $self->cached_pinterp->update({
+        status => 'fully-cached'
+    });
 
 }
 
@@ -682,7 +572,6 @@ sub cache_result{
     confess "Individual results should be hashrefs. This one isn't: $result" unless ref $result eq ref {};
 
     my $guard = $self->sm->schema->txn_scope_guard;
-    #my $id = $self->cached_pinterp->id;
     my $group = $self->sm->table('result_group')->create({
         pinterp_id => +$self->cached_pinterp->id
     });
@@ -696,8 +585,6 @@ sub cache_result{
         });
     }
     $guard->commit;
-
-    #return $id;
 }
 
 
@@ -765,7 +652,6 @@ sub next_result_as_task{
 
     } else {
 
-        #my $group = $self->cached_result_group_rs->next;
         my $group = $self->working_result_group_rs->next;
 
         if ( $group ){
@@ -787,15 +673,15 @@ sub next_result_as_task{
 
 
 
-#sub count_results{
-#    my ($self) = @_;
+sub count_results{
+    my ($self) = @_;
 
-#    if ($self->results_iterator){
-#        return +$self->results_iterator->count->();
-#    } else {
-#        return +$self->cached_result_group_rs->count;
-#    }
-#}
+    if ($self->results_iterator){
+        return +$self->results_iterator->count->();
+    } else {
+        return +$self->cached_result_group_rs->count;
+    }
+}
 
 
 
@@ -852,15 +738,12 @@ sub pipe_to{
 
     my $tm = $self->thread_manager;
     $tm->forks(0);
-    #$tm->run_id( $self->run_id );
-    #$tm->run_info->thread_id( $self->rinfo->thread_id );
     
-#    my $total = $self->count_results;
-#    $total = scalar(@$plan) * $self->count_results if $total > 0;
+    my $ni = $self->count_results;
     
-    my ($i0, $p0 ) = $self->get_xbranch_resume_indices;
-    #my $i0 = 0;
-    #my $p0 = 0;
+#    my ($i0, $p0 ) = $self->get_xbranch_resume_indices;
+    my $i0 = 0;
+    my $p0 = 0;
 
     for my $pi ($p0..$#$plan){
 
@@ -870,13 +753,14 @@ sub pipe_to{
 
         while( my $input_item = $self->next_result ){
             $ii++;
+            my $count = $pi * $ni + $ii;
+            my $last_rec_cond = $pi == $#$plan && $ii == $ni ? 1 : 0;
 
             $tm->execute( sub{
-                    #my ($thread_id) = @_;
-                    $self->execute_child_task( $plan->[$pi], $input_item ); #, $thread_id );
+                    $self->execute_child_task( $plan->[$pi], $input_item );
                 },
-                1,
-                0
+                $count,
+                $last_rec_cond
             );
 
             $self->sm->table('xbranch')->find({
@@ -912,46 +796,6 @@ sub get_xbranch_resume_indices{
 
 
 
-#sub pipe_to{
-#    my ($self,$plan) = @_;
-
-#    my $tm = $self->thread_manager;
-#    $tm->forks(0);
-#    #$tm->run_id( $self->run_id );
-#    #$tm->run_info->thread_id( $self->rinfo->thread_id );
-#    
-#    my $count = 0;
-#    my $total = $self->count_results;
-#    $total = scalar(@$plan) * $self->count_results if $total > 0;
-#    
-#    for my $pi (0..$#plan){
-#        my $
-#    foreach my $plan_item (@$plan){
-
-#        $self->reset_results_iterator;
-#        while( my $input_item = $self->next_result ){
-
-#            $count++;
-
-#            $tm->execute( sub{
-#                    #my ($thread_id) = @_;
-#                    $self->execute_child_task( $plan_item, $input_item ); #, $thread_id );
-#                }, 
-#                $count,
-#                $count == $total
-#            );
-
-#            $self->sm->table('xbranch')->find({
-#                id => $self->xbranch_ids->[0]
-#            })->update({
-#                child_xcount => $count
-#            });
-#        }
-#    }
-
-#    $tm->wait_children;
-#}
-
 
 
 
@@ -961,7 +805,6 @@ sub execute_child_task{
     my $logger = Log::Log4perl->get_logger;
 
     my $task = $self->task_from_plan($plan);
-    #$task->run_info->thread_id( $thread_id );
     $task->input($input);
     $self->add_history( $task );
 
@@ -1050,9 +893,6 @@ sub task_from_plan{
         sm => $self->sm,
         gm => $self->gm,
         settings => $self->settings,
-        #rinfo => $self->rinfo,
-#        run_id => $self->run_id,
-#        job_id => $self->job_id,
         thread_manager => $self->thread_manager,
         plan => $plan
     );
